var indexSectionsWithContent =
{
  0: "bde",
  1: "bde",
  2: "e",
  3: "e",
  4: "e"
};

var indexSectionNames =
{
  0: "all",
  1: "classes",
  2: "files",
  3: "functions",
  4: "typedefs"
};

var indexSectionLabels =
{
  0: "All",
  1: "Classes",
  2: "Files",
  3: "Functions",
  4: "Typedefs"
};

